@@ -73,16 +73,16 @@ inline void F5(u32bit& A, u32bit B, u32bit& C, u32bit D, u32bit E,
 /*
 * RIPEMD-160 Compression Function
 */
-void RIPEMD_160::compress_n(const byte input[], u32bit blocks)
+void RIPEMD_160::compress_n(const byte input[], size_t blocks)
    {
    const u32bit MAGIC2 = 0x5A827999, MAGIC3 = 0x6ED9EBA1,
                 MAGIC4 = 0x8F1BBCDC, MAGIC5 = 0xA953FD4E,
                 MAGIC6 = 0x50A28BE6, MAGIC7 = 0x5C4DD124,
                 MAGIC8 = 0x6D703EF3, MAGIC9 = 0x7A6D76E9;
 
-   for(u32bit i = 0; i != blocks; ++i)
+   for(size_t i = 0; i != blocks; ++i)
       {
-      load_le(M.begin(), input, M.size());
+      load_le(&M[0], input, M.size());
 
       u32bit A1 = digest[0], A2 = A1, B1 = digest[1], B2 = B1,
              C1 = digest[2], C2 = C1, D1 = digest[3], D2 = D1,
@@ -180,7 +180,7 @@ void RIPEMD_160::compress_n(const byte input[], u32bit blocks)
       digest[4] = digest[0] + B1 + C2;
       digest[0] = C1;
 
-      input += HASH_BLOCK_SIZE;
+      input += hash_block_size();
       }
    }
 
@@ -189,8 +189,8 @@ void RIPEMD_160::compress_n(const byte input[], u32bit blocks)
 */
 void RIPEMD_160::copy_out(byte output[])
    {
-   for(u32bit j = 0; j != OUTPUT_LENGTH; j += 4)
-      store_le(digest[j/4], output + j);
+   for(size_t i = 0; i != output_length(); i += 4)
+      store_le(digest[i/4], output + i);
    }
 
 /*
@@ -199,7 +199,7 @@ void RIPEMD_160::copy_out(byte output[])
 void RIPEMD_160::clear()
    {
    MDx_HashFunction::clear();
-   M.clear();
+   zeroise(M);
    digest[0] = 0x67452301;
    digest[1] = 0xEFCDAB89;
    digest[2] = 0x98BADCFE;
